==> oto-service-api-0.0.11-20221205.074318-9-sources.jar: cn/com/duiba/oto/oto/service/api/remoteservice/cust/RemoteOtoCustPlanService.java <==
package cn.com.duiba.oto.oto.service.api.remoteservice.cust;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.oto.dto.oto.cust.OtoCustPlanDto;
import cn.com.duiba.oto.param.oto.cust.OtoCustPlanSaveParam;
import cn.com.duiba.oto.param.oto.cust.OtoCustPlanSearchParam;
import cn.com.duiba.oto.param.oto.cust.OtoCustPlanUpdateParam;
import feign.Param;

import java.util.List;


@AdvancedFeignClient
public interface RemoteOtoCustPlanService {

    /**
     * 根据条件查询客户计划 分页
     * @param param 查询条件
     * @return 结果
     */
    List<OtoCustPlanDto> getCustPlanListByParam(OtoCustPlanSearchParam param);

    /**
     * 根据条件查询客户计划
     * @param param 查询条件
     * @return 结果
     */
    Long getCustPlanCountByParam(OtoCustPlanSearchParam param);

    /**
     * 批量保存
     * @param params 参数
     * @return 保存成功数量
     */
    int batchSaveCustPlan(List<OtoCustPlanSaveParam> params);

    /**
     * 根据条件查询客户计划 不分页
     * @param param 查询条件
     * @return 结果
     */
    List<OtoCustPlanDto> selectCustPlanListByParam(OtoCustPlanSearchParam param);

    /**
     * 根据计划ID查询计划详情
     * @param ids 计划ID
     * @return 结果
     */
    List<OtoCustPlanDto> getCustPlanListByIds(List<Long> ids);

    /**
     * 修改
     * @param param 参数
     * @return 结果
     */
    boolean updateByParam(OtoCustPlanUpdateParam param);

    /**
     * 批量更新计划状态
     * @param ids
     * @return
     */
    int batchUpdatePlanStatus(@Param("ids") List<Long> ids, @Param("status") Integer status);

    /**
     * 根据条件查询
     */
    List<OtoCustPlanDto> selectByParamReturnIdOrder(OtoCustPlanSearchParam searchParam);
}

==> oto-service-api-0.0.12-20221209.092545-7-sources.jar: cn/com/duiba/oto/oto/service/api/remoteservice/cust/RemoteOtoCustPlanService.java <==
package cn.com.duiba.oto.oto.service.api.remoteservice.cust;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.oto.dto.oto.cust.OtoCustPlanDto;
import cn.com.duiba.oto.param.oto.cust.OtoCustPlanSaveParam;
import cn.com.duiba.oto.param.oto.cust.OtoCustPlanSearchParam;
import cn.com.duiba.oto.param.oto.cust.OtoCustPlanUpdateParam;
import feign.Param;

import java.util.List;


@AdvancedFeignClient
public interface RemoteOtoCustPlanService {

    /**
     * 根据条件查询客户计划 分页
     * @param param 查询条件
     * @return 结果
     */
    List<OtoCustPlanDto> getCustPlanListByParam(OtoCustPlanSearchParam param);

    /**
     * 根据条件查询客户计划
     * @param param 查询条件
     * @return 结果
     */
    Long getCustPlanCountByParam(OtoCustPlanSearchParam param);

    /**
     * 批量保存
     * @param params 参数
     * @return 保存成功数量
     */
    int batchSaveCustPlan(List<OtoCustPlanSaveParam> params);

    /**
     * 根据条件查询客户计划 不分页
     * @param param 查询条件
     * @return 结果
     */
    List<OtoCustPlanDto> selectCustPlanListByParam(OtoCustPlanSearchParam param);

    /**
     * 根据计划ID查询计划详情
     * @param ids 计划ID
     * @return 结果
     */
    List<OtoCustPlanDto> getCustPlanListByIds(List<Long> ids);

    /**
     * 修改
     * @param param 参数
     * @return 结果
     */
    boolean updateByParam(OtoCustPlanUpdateParam param);

    /**
     * 批量更新计划状态
     * @param ids
     * @return
     */
    int batchUpdatePlanStatus(@Param("ids") List<Long> ids, @Param("status") Integer status);

    /**
     * 根据条件查询
     */
    List<OtoCustPlanDto> selectByParamReturnIdOrder(OtoCustPlanSearchParam searchParam);

    /**
     * 删除客户进行中的计划
     * @param custId 客户ID
     * @param status 计划状态
     */
    int deleteByCustId(Long custId, Integer status);
}
